@@ -3,7 +3,7 @@ import re
 
 class SideStep:
 
-    def __init__(self, step):
+    def __init__(self, step, pipeline_id):
         self.step = step
         self.pipeline_id = pipeline_id
 
